@@ -3,6 +3,7 @@ from hasty.client import Client
 from hasty.dataset import Dataset
 from hasty.export_job import ExportJob
 from hasty.image import Image
+from hasty.inference import Attributer, Detector, InstanceSegmentor, SemanticSegmentor
 from hasty.label import Label
 from hasty.label_class import LabelClass
 from hasty.project import Project
@@ -16,15 +17,21 @@ def int_or_str(value):
         return value
 
 
-__version__ = '0.1.0'
+__version__ = '0.2.2'
 VERSION = tuple(map(int_or_str, __version__.split('.')))
 
 __all__ = [
     'Attribute',
+    'Attributer',
     'Client',
     'Dataset',
+    'Detector',
     'ExportJob',
+    'Image',
+    'InstanceSegmentor',
+    'Label',
     'LabelClass',
     'Project',
+    'SemanticSegmentor',
     'label_utils'
 ]
