@@ -14,3 +14,12 @@ class LimitExceededException(Exception):
     @classmethod
     def max_labels_per_batch(cls, got):
         return LimitExceededException(f"Max number of labels per batch is 100, got {got}")
+
+
+class InferenceException(Exception):
+    def __init__(self, message):
+        self.message = message
+
+    @classmethod
+    def model_not_loaded(cls):
+        return InferenceException("Model not loaded")
